if __name__ == '__main__':
    import sys
    import steem.cli

    sys.exit(steem.cli.legacyentry())
